@@ -1,4 +1,3 @@
-
 package DateTime::Set;
 
 use strict;
@@ -16,7 +15,7 @@ use constant INFINITY     =>       100 ** 100 ** 100 ;
 use constant NEG_INFINITY => -1 * (100 ** 100 ** 100);
 
 BEGIN {
-    $VERSION = '0.32';
+    $VERSION = '0.3500';
 }
 
 
@@ -199,7 +198,7 @@ sub from_recurrence {
     $param{previous} = delete $args{previous};
 
     $param{span} = delete $args{span};
-    # they might be specifying a span using begin / end
+    # they might be specifying a span using start / end
     $param{span} = DateTime::Span->new( %args ) if keys %args;
 
     my $self = {};
@@ -336,7 +335,7 @@ sub _callback_previous {
     $previous = $callback_next->( $previous );
     if ($previous >= $value) 
     {
-        # This error happens if the event frequency oscilates widely
+        # This error happens if the event frequency oscillates widely
         # (more than 100% of difference from one interval to next)
         my @freq = $freq->deltas;
         print STDERR "_callback_previous: Delta components are: @freq\n";
@@ -379,7 +378,7 @@ sub _callback_next {
     $next = $callback_previous->( $next );
     if ($next <= $value) 
     {
-        # This error happens if the event frequency oscilates widely
+        # This error happens if the event frequency oscillates widely
         # (more than 100% of difference from one interval to next)
         my @freq = $freq->deltas;
         print STDERR "_callback_next: Delta components are: @freq\n";
@@ -508,7 +507,7 @@ sub as_list {
     return if $set->{set}->is_null;  # nothing = empty
 
     # Note: removing this line means we may end up in an infinite loop!
-    ## return undef if $set->{set}->is_too_complex;  # undef = no begin/end
+    ## return undef if $set->{set}->is_too_complex;  # undef = no start/end
  
     return undef
         if $set->max->is_infinite ||
@@ -767,9 +766,9 @@ Creates a new set specified via a "recurrence" callback.
 
 The C<span> parameter is optional. It must be a C<DateTime::Span> object.
 
-The span can also be specified using C<begin> / C<after> and C<before>
-/ C<end> parameters, as in the C<DateTime::Span> constructor.  In this
-case, if there is a C<span> parameter it will be ignored.
+The span can also be specified using C<start> / C<after> and C<end> /
+C<before> parameters, as in the C<DateTime::Span> constructor.  In
+this case, if there is a C<span> parameter it will be ignored.
 
     $months = DateTime::Set->from_recurrence(
         after => $dt_now,
@@ -1025,6 +1024,10 @@ These set operations result in a boolean value.
 These methods can accept a C<DateTime> list, a C<DateTime::Set>, a
 C<DateTime::Span>, or a C<DateTime::SpanSet> object as an argument.
 
+intersects() returns 1 for true, and 0 for false. In a few cases
+the algorithm can't decide if the sets intersect at all, and 
+intersects() will return C<undef>.
+
 =item * previous
 
 =item * next
